@@ -75,8 +75,11 @@ QByteArray QtPrivate::qtro_classinfo_signature(const QMetaObject *metaObject)
     return QByteArray{};
 }
 
-inline bool qtro_is_cloned_method(const QMetaObject *mobj, int local_method_index)
+inline bool qtro_is_cloned_method(const QMetaObject *mobj, int index)
 {
+    int local_method_index = index - mobj->methodOffset();
+    if (local_method_index < 0 && mobj->superClass())
+        return qtro_is_cloned_method(mobj->superClass(), index);
     const auto priv = reinterpret_cast<const QtPrivate::QMetaObjectPrivate*>(mobj->d.data);
     Q_ASSERT(local_method_index < priv->methodCount);
     int handle = priv->methodData + 5 * local_method_index;
@@ -113,7 +116,10 @@ QRemoteObjectSourceBase::QRemoteObjectSourceBase(QObject *obj, Private *d, const
             if (QMetaType::typeFlags(property.userType()).testFlag(QMetaType::PointerToQObject)) {
                 auto propertyMeta = QMetaType::metaObjectForType(property.userType());
                 QObject *child = property.read(m_object).value<QObject *>();
-                if (propertyMeta->inherits(&QAbstractItemModel::staticMetaObject)) {
+                const QMetaObject *meta = child ? child->metaObject() : propertyMeta;
+                if (!meta)
+                    continue;
+                if (meta->inherits(&QAbstractItemModel::staticMetaObject)) {
                     const auto modelInfo = api->m_models.at(modelIndex++);
                     QAbstractItemModel *model = qobject_cast<QAbstractItemModel *>(child);
                     QAbstractItemAdapterSourceAPI<QAbstractItemModel, QAbstractItemModelSourceAdapter> *modelApi =
@@ -188,9 +194,8 @@ void QRemoteObjectSourceBase::setConnections()
         const auto targetMeta = isAdapter ? m_adapter->metaObject() : meta;
 
         // don't connect cloned signals, or we end up with multiple emissions
-        if (qtro_is_cloned_method(targetMeta, sourceIndex - targetMeta->methodOffset()))
+        if (qtro_is_cloned_method(targetMeta, sourceIndex))
             continue;
-
         // This basically connects the parent Signals (note, all dynamic properties have onChange
         //notifications, thus signals) to us.  Normally each Signal is mapped to a unique index,
         //but since we are forwarding them all, we keep the offset constant.
@@ -455,13 +460,20 @@ DynamicApiMap::DynamicApiMap(QObject *object, const QMetaObject *metaObject, con
     const int propCount = metaObject->propertyCount();
     const int propOffset = metaObject->propertyOffset();
     m_properties.reserve(propCount-propOffset);
-    int i = 0;
-    for (i = propOffset; i < propCount; ++i) {
+    QSet<int> invalidSignals;
+    for (int i = propOffset; i < propCount; ++i) {
         const QMetaProperty property = metaObject->property(i);
         if (QMetaType::typeFlags(property.userType()).testFlag(QMetaType::PointerToQObject)) {
             auto propertyMeta = QMetaType::metaObjectForType(property.userType());
             QObject *child = property.read(object).value<QObject *>();
-            if (propertyMeta->inherits(&QAbstractItemModel::staticMetaObject)) {
+            const QMetaObject *meta = child ? child->metaObject() : propertyMeta;
+            if (!meta) {
+                const int notifyIndex = metaObject->property(i).notifySignalIndex();
+                if (notifyIndex != -1)
+                    invalidSignals << notifyIndex;
+                continue;
+            }
+            if (meta->inherits(&QAbstractItemModel::staticMetaObject)) {
                 const QByteArray name = QByteArray::fromRawData(property.name(),
                                                                 qstrlen(property.name()));
                 const QByteArray infoName = name.toUpper() + QByteArrayLiteral("_ROLES");
@@ -475,12 +487,15 @@ DynamicApiMap::DynamicApiMap(QObject *object, const QMetaObject *metaObject, con
                                        QString::fromLatin1(property.name()),
                                        roleInfo});
             } else {
-                const QMetaObject *meta = child ? child->metaObject() : propertyMeta;
                 QString typeName = QtRemoteObjects::getTypeNameAndMetaobjectFromClassInfo(meta);
                 if (typeName.isNull()) {
-                    typeName = QString::fromLatin1(propertyMeta->className());
+                    typeName = QString::fromLatin1(meta->className());
+                    if (typeName.contains(QLatin1String("QQuick")))
+                        typeName.remove(QLatin1String("QQuick"));
+                    else if (int index = typeName.indexOf(QLatin1String("_QMLTYPE_")))
+                        typeName.truncate(index);
                     // TODO better way to ensure we have consistent typenames between source/replicas?
-                    if (typeName.endsWith(QLatin1String("Source")))
+                    else if (typeName.endsWith(QLatin1String("Source")))
                         typeName.chop(6);
                 }
 
@@ -499,11 +514,13 @@ DynamicApiMap::DynamicApiMap(QObject *object, const QMetaObject *metaObject, con
     }
     const int methodCount = metaObject->methodCount();
     const int methodOffset = metaObject->methodOffset();
-    for (i = methodOffset; i < methodCount; ++i) {
+    for (int i = methodOffset; i < methodCount; ++i) {
         const QMetaMethod mm = metaObject->method(i);
         const QMetaMethod::MethodType m = mm.methodType();
         if (m == QMetaMethod::Signal) {
-            if (m_signals.indexOf(i) >= 0) //Already added as a property notifier
+            if (m_signals.indexOf(i) >= 0)  // Already added as a property notifier
+                continue;
+            if (invalidSignals.contains(i)) // QObject with no metatype
                 continue;
             m_signals << i;
         } else if (m == QMetaMethod::Slot || m == QMetaMethod::Method)
