@@ -342,7 +342,7 @@ private slots:
 
         // set property on the replica (test property change packet)
         {
-            QSignalSpy spy(tc_rep.data(), SIGNAL(classEnumChanged(TestClassReplica::ClassEnum)));
+            QSignalSpy spy(tc_rep.data(), &TestClassReplica::classEnumChanged);
             QVERIFY(spy.isValid());
             tc_rep->pushClassEnum(TestClassReplica::Two);
             QVERIFY(spy.count() || spy.wait());
@@ -352,7 +352,7 @@ private slots:
 
         // set property on the source (test property change packet)
         {
-            QSignalSpy spy(tc_rep.data(), SIGNAL(classEnumChanged(TestClassReplica::ClassEnum)));
+            QSignalSpy spy(tc_rep.data(), &TestClassReplica::classEnumChanged);
             tc.setClassEnum(TestClassSimpleSource::One);
             QVERIFY(spy.wait());
 
@@ -380,7 +380,7 @@ private slots:
 
         // write enum on the dynamic replica
         {
-            QSignalSpy spy(tc_rep.data(), SIGNAL(classEnumRWChanged(TestClassReplica::ClassEnum)));
+            QSignalSpy spy(tc_rep.data(), &TestClassReplica::classEnumRWChanged);
             property.write(tc_repDynamic.data(), TestClassReplica::Two);
             QVERIFY(spy.wait());
 
@@ -401,7 +401,7 @@ private slots:
 
         // ensure write enum fails on ReadPush
         {
-            QSignalSpy spy(tc_rep.data(), SIGNAL(classEnumChanged(TestClassReplica::ClassEnum)));
+            QSignalSpy spy(tc_rep.data(), &TestClassReplica::classEnumChanged);
             bool res = property.write(tc_repDynamic.data(), TestClassReplica::Two);
             QVERIFY(!res);
             int methodIndex = metaObject->indexOfMethod("pushClassEnum(TestClassReplica::ClassEnum)");
@@ -470,7 +470,7 @@ private slots:
         instances = client->instances<EngineReplica>();
         QCOMPARE(instances, QStringList({"Engine", "Engine2"}));
 
-        QSignalSpy spy(engine_r.data(), SIGNAL(stateChanged(State,State)));
+        QSignalSpy spy(engine_r.data(), &QRemoteObjectReplica::stateChanged);
         host->disableRemoting(&e);
         spy.wait();
         QCOMPARE(spy.count(), 1);
@@ -510,7 +510,7 @@ private slots:
                 }
             });
 
-        QSignalSpy addedSpy(client->registry(), SIGNAL(remoteObjectAdded(QRemoteObjectSourceLocation)));
+        QSignalSpy addedSpy(client->registry(), &QRemoteObjectRegistry::remoteObjectAdded);
 
         Engine e;
         e.setRpm(1111);
@@ -655,8 +655,8 @@ private slots:
         host->enableRemoting(localEngine.data());
         QCOMPARE(host->registry()->sourceLocations().keys().isEmpty(), true);
 
-        QSignalSpy spy(host->registry(), SIGNAL(initialized()));
-        QSignalSpy addedSpy(host->registry(), SIGNAL(remoteObjectAdded(QRemoteObjectSourceLocation)));
+        QSignalSpy spy(host->registry(), &QRemoteObjectRegistry::initialized);
+        QSignalSpy addedSpy(host->registry(), &QRemoteObjectRegistry::remoteObjectAdded);
         setupRegistry();
         bool added = addedSpy.wait();
         QVERIFY(spy.count() > 0);
@@ -696,7 +696,7 @@ private slots:
         setupClient();
 
         const QScopedPointer<EngineReplica> engine_r(client->acquire<EngineReplica>());
-        QSignalSpy spy(engine_r.data(), SIGNAL(rpmChanged(int)));
+        QSignalSpy spy(engine_r.data(), &EngineReplica::rpmChanged);
         e.setRpm(2345);
 
         spy.wait();
@@ -717,7 +717,7 @@ private slots:
 
         setupClient();
 
-        QSignalSpy spy(this, SIGNAL(forwardResult(int)));
+        QSignalSpy spy(this, &tst_Integration::forwardResult);
         QScopedPointer<QRemoteObjectDynamicReplica> engine_dr(client->acquireDynamic(QStringLiteral("Engine")));
         connect(engine_dr.data(), &QRemoteObjectDynamicReplica::initialized, [&]()
             {
@@ -785,7 +785,7 @@ private slots:
         QCOMPARE(reply.error(), QRemoteObjectPendingCall::InvalidMessage);
 
         QRemoteObjectPendingCallWatcher watcher(reply);
-        QSignalSpy spy(&watcher, SIGNAL(finished(QRemoteObjectPendingCallWatcher *)));
+        QSignalSpy spy(&watcher, &QRemoteObjectPendingCallWatcher::finished);
         spy.wait();
         QCOMPARE(spy.count(), 1);
 
@@ -939,7 +939,7 @@ private slots:
         QCOMPARE(engine_r->cylinders(), 4); // Default value
         engine_r->waitForSource();
         QCOMPARE(engine_r->cylinders(), 6);
-        QSignalSpy spy(engine_r.data(), SIGNAL(rpmChanged(int)));
+        QSignalSpy spy(engine_r.data(), &EngineReplica::rpmChanged);
         engine_r->setRpm(42);
         spy.wait();
         QCOMPARE(spy.count(), 1);
@@ -957,7 +957,7 @@ private slots:
         const QScopedPointer<EngineReplica> engine_r(client->acquire<EngineReplica>());
         engine_r->waitForSource();
         QCOMPARE(engine_r->started(), false);
-        QSignalSpy spy(engine_r.data(), SIGNAL(startedChanged(bool)));
+        QSignalSpy spy(engine_r.data(), &EngineReplica::startedChanged);
         engine_r->pushStarted(true);
         spy.wait();
         QCOMPARE(spy.count(), 1);
@@ -1000,7 +1000,7 @@ private slots:
         engine_r->waitForSource();
         QCOMPARE(engine_r->rpm(), 0);
 
-        QSignalSpy spy(engine_r.data(), SIGNAL(rpmChanged(int)));
+        QSignalSpy spy(engine_r.data(), &EngineReplica::rpmChanged);
         engine_r->increaseRpm(1000);
         spy.wait();
         QCOMPARE(spy.count(), 1);
@@ -1073,7 +1073,7 @@ private slots:
         setupClient();
 
         const QScopedPointer<EngineReplica> engine_r1(client->acquire< EngineReplica >());
-        QSignalSpy spy_r1(engine_r1.data(), SIGNAL(rpmChanged(int)));
+        QSignalSpy spy_r1(engine_r1.data(), &EngineReplica::rpmChanged);
         engine_r1->waitForSource();
         QCOMPARE(engine_r1->rpm(), e.rpm());
         QCOMPARE(spy_r1.count(), 1);
@@ -1082,7 +1082,7 @@ private slots:
         // which leads to different semantics for first and second replicas. Specifically, there is no
         // way to hook in to initialized and the initial notify signals. We should consider changing this.
         const QScopedPointer<EngineReplica> engine_r2(client->acquire< EngineReplica >());
-//        QSignalSpy spy_r2(engine_r2.data(), SIGNAL(rpmChanged(int)));
+//        QSignalSpy spy_r2(engine_r2.data(), &EngineReplica::rpmChanged);
 //        engine_r2->waitForSource();
         QCOMPARE(engine_r2->rpm(), e.rpm());
 //        QCOMPARE(spy_r2.count(), 1);
@@ -1243,7 +1243,7 @@ private slots:
     {
         QRemoteObjectNode _client;
         Q_SET_OBJECT_NAME(_client);
-        QSignalSpy errorSpy(&_client, SIGNAL(error(QRemoteObjectNode::ErrorCode)));
+        QSignalSpy errorSpy(&_client, &QRemoteObjectNode::error);
         QVERIFY(!_client.connectToNode(QUrl(QLatin1String("invalid:invalid"))));
         QCOMPARE(errorSpy.count(), 1);
         auto emittedErrorCode = errorSpy.first().at(0).value<QRemoteObjectNode::ErrorCode>();
@@ -1258,7 +1258,7 @@ private slots:
         setupHost();
         Engine e;
         host->enableRemoting<EngineSourceAPI>(&e);
-        QSignalSpy spy(engine_d.data(), SIGNAL(rpmChanged(int)));
+        QSignalSpy spy(engine_d.data(), &EngineReplica::rpmChanged);
         e.setRpm(50);
 
         spy.wait();
